==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/GridCellPositionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridCellPositionDescription } from "./GridCellPositionDescription";
/**
 * @hidden
 */
var GridCellPositionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridCellPositionDescriptionMetadata, _super);
    function GridCellPositionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridCellPositionDescriptionMetadata.b = function (a) {
        if (GridCellPositionDescriptionMetadata.a == null) {
            GridCellPositionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridCellPositionDescriptionMetadata.c(GridCellPositionDescriptionMetadata.a);
        }
        if (a.g(GridCellPositionDescriptionMetadata.a)) {
            return;
        }
        a.s(GridCellPositionDescriptionMetadata.a);
    };
    GridCellPositionDescriptionMetadata.c = function (a) {
        a.item("RowIndex", "Number:int");
        a.item("ColumnUniqueKey", "String");
    };
    GridCellPositionDescriptionMetadata.d = function (a) {
        GridCellPositionDescriptionMetadata.b(a);
        a.u("GridCellPosition", function () { return new GridCellPositionDescription(); });
        a.t("GridCellPosition", GridCellPositionDescriptionMetadata.a);
    };
    GridCellPositionDescriptionMetadata.$t = markType(GridCellPositionDescriptionMetadata, 'GridCellPositionDescriptionMetadata');
    GridCellPositionDescriptionMetadata.a = null;
    return GridCellPositionDescriptionMetadata;
}(Base));
export { GridCellPositionDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GridCellPositionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridCellPositionDescription } from "./GridCellPositionDescription";
/**
 * @hidden
 */
var GridCellPositionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridCellPositionDescriptionMetadata, _super);
    function GridCellPositionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridCellPositionDescriptionMetadata.b = function (a) {
        if (GridCellPositionDescriptionMetadata.a == null) {
            GridCellPositionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridCellPositionDescriptionMetadata.c(GridCellPositionDescriptionMetadata.a);
        }
        if (a.j(GridCellPositionDescriptionMetadata.a)) {
            return;
        }
        a.y(GridCellPositionDescriptionMetadata.a);
    };
    GridCellPositionDescriptionMetadata.c = function (a) {
        a.item("RowIndex", "Number:int");
        a.item("ColumnUniqueKey", "String");
    };
    GridCellPositionDescriptionMetadata.d = function (a) {
        GridCellPositionDescriptionMetadata.b(a);
        a.aa("GridCellPosition", function () { return new GridCellPositionDescription(); });
        a.z("GridCellPosition", GridCellPositionDescriptionMetadata.a);
    };
    GridCellPositionDescriptionMetadata.$t = markType(GridCellPositionDescriptionMetadata, 'GridCellPositionDescriptionMetadata');
    GridCellPositionDescriptionMetadata.a = null;
    return GridCellPositionDescriptionMetadata;
}(Base));
export { GridCellPositionDescriptionMetadata };
